@@ -18,7 +18,7 @@ sub read_hash {
         my $patch_dir = $args->{root} . $args->{config_dir} . "patches";
         $logger->info("Checking patches directory ($patch_dir)");
 
-        $self->read_patch_series( $obj, $check, $patch_dir );
+        $self->read_patch_series( $obj, $check, $patch_dir, $args );
     }
     else {
         $self->SUPER::read_hash(@_);
@@ -26,7 +26,7 @@ sub read_hash {
 }
 
 sub read_patch_series {
-    my ( $self, $hash, $check, $patch_dir ) = @_;
+    my ( $self, $hash, $check, $patch_dir, $args ) = @_;
 
     my $series_files = "$patch_dir/series";
 
@@ -49,9 +49,25 @@ sub read_patch_series {
 		$pname =~ s/#.*//; # skip comment
         next unless $pname =~ /\w/;    # skip empty lines
         my $obj = $hash->fetch_with_id($pname);
-        $obj->init;
-        my $location = $obj->name;
-        $logger->info("found patch $pname, stored in $location ($obj)");
+        eval { $obj->init; };
+        my $e;
+        if ($e = Exception::Class->caught('Config::Model::Exception::Syntax')) {
+            if ( $args->{check} eq 'yes' ) {
+                my $msg = $e ->message. ". Use -force option to override" ;
+                ref($e) -> throw(message => $msg);
+            }
+            else {
+                warn "Warning: Ignoring patch $pname: ", $e->message,"\n";
+            }
+            $hash->delete($pname);
+        }
+        elsif ( $e = Exception::Class->caught() ) {
+            ref $e ? $e->rethrow : die $e;
+        }
+        elsif ($logger->is_info) {
+            my $location = $obj->name;
+            $logger->info("found patch $pname, stored in $location ($obj)");
+        }
     }
 
     $ser_io->close;
