@@ -7,6 +7,7 @@ extends 'Config::Model::Backend::Any';
 
 with 'Config::Model::Backend::DpkgSyntax';
 
+use 5.10.1;
 use Carp;
 use Config::Model::Exception ;
 use Config::Model::ObjTreeScanner ;
@@ -115,7 +116,7 @@ sub read {
         elsif (defined $section{license}) {
             my ($v,$l, $a) = @{$section{license}} ;
             # need to extract license name from license text
-            my ($lic_name) = ($v =~ /^(\S+)/) ;
+            my ($lic_name) = ($v =~ /^([^\n]+)/) ;
             if (not defined $lic_name) {
                 $lic_name = 'other';
                 $a = $section{license}[2] = q!use 'other' to replace undefined license name!;
@@ -157,8 +158,6 @@ sub read {
             if ($key =~ /licen[sc]e/i) {
                 my @lic_text = split /\n/,$v ;
                 my ($lic_name) = shift @lic_text ;
-                # get rid of potential 'with XXX exception'
-                $lic_name =~ s/\s+with\s+\w+\s+exception//g ;
                 $logger->debug("adding license text for '$lic_name': '@lic_text'");
 
                 # lic_obj may not be defined in -force mode
@@ -297,14 +296,6 @@ sub _store_file_license {
     my ( $lic_line, $lic_text ) = split /\n/, $v, 2 ;
     $lic_line =~ s/\s+$//;
 
-    # too much hackish is bad for health
-    if ( $lic_line =~ /with\s+(\w+)\s+exception/ ) {
-        my $exception = $1;
-        $lic_object->fetch_element('exception') -> store( value => $exception, check => $check );
-        $lic_line =~ s/\s+with\s+\w+\s+exception//;
-        $logger->debug("license exception: $exception");
-    }
-    
     $lic_line =~ s/\s*\|\s*/ or /g; # old way of expressing or condition
     $lic_line ||= 'other' ;
     $logger->debug("license abbrev: $lic_line");
@@ -366,8 +357,6 @@ sub write {
         # your custom code using $data_ref
         $logger->debug("file_license_cb called on ",$node->name);
         my $lic_text  = $node->fetch_element_value('short_name');
-        my $exception = $node->fetch_element_value('exception');
-        $lic_text .= " with $exception exception" if defined $exception;
         my $full_lic_text = $node->fetch_element_value('full_license');
         $lic_text .= "\n" . $full_lic_text if defined $full_lic_text;
         push @{$data_ref->{one}}, License => $lic_text if defined $lic_text;
@@ -417,7 +406,6 @@ sub write {
     };
     
     my $scan = Config::Model::ObjTreeScanner->new(
-        experience      => 'master',              # consider all values
         leaf_cb         => $my_leaf_cb,
         #string_value_cb => $my_string_cb,
         list_element_cb => $my_list_element_cb,
