@@ -169,7 +169,7 @@ depend: pkg_dep | variable
 # For the allowed stuff after ${foo}, see #702792
 variable: /\${[\w:\-]+}[\w\.\-~+]*/
 
-pkg_dep: pkg_name dep_version(?) arch_restriction(?) profile_restriction(?) {
+pkg_dep: pkg_name dep_version(?) arch_restriction(?) profile_restriction(s?) {
     my $dv = $item[2] ;
     my $ar = $item[3] ;
     my @ret = ( $item{pkg_name} ) ;
@@ -181,7 +181,7 @@ pkg_dep: pkg_name dep_version(?) arch_restriction(?) profile_restriction(?) {
 
 profile_restriction: '<' profile(s) '>'
 
-profile: not(?) 'profile.' profile_name
+profile: not(?) profile_name
 
 profile_name: /[a-z][a-z0-9-]*/
 
@@ -435,7 +435,7 @@ sub check_depend_chain {
 # does modify $input when applying fix
 sub check_perl_lib_dep {
     my ($self, $apply_fix, $pname, $actual_dep, $depend, $input) = @_;
-    $logger->debug("called with $actual_dep with apply_fix $apply_fix");
+    $logger->debug("called for $pname with $actual_dep with apply_fix $apply_fix");
 
     my ( $dep_name, $oper, $dep_v ) = @$depend;
 
@@ -451,6 +451,11 @@ sub check_perl_lib_dep {
     my @dep_name_as_perl = Module::CoreList->find_modules(qr/^$pname$/i) ;
     return 1 unless @dep_name_as_perl;
 
+    my $deprecated = Module::CoreList->deprecated_in($dep_name_as_perl[0]) ;
+    $logger->debug("dual life $dep_name is deprecated with perl $deprecated") if $deprecated;
+    my $removed    = Module::CoreList->removed_from($dep_name_as_perl[0]) ;
+    $logger->debug("dual life $dep_name is removed from perl $removed") if $removed;
+
     return 1 if (defined $dep_v && $dep_v =~ m/^\$/) ;
 
     my @ideal_perl_dep = qw/perl/ ;
@@ -509,7 +514,7 @@ sub check_perl_lib_dep {
 			push @ideal_lib_dep, '>=', $dep_v if $has_older_lib;
 		}
 	}
-	elsif ($has_older_perl) {
+	elsif ($has_older_perl or $removed or $deprecated) {
 		push @ideal_lib_dep, $dep_name;
 	}
 
@@ -521,9 +526,10 @@ sub check_perl_lib_dep {
 		"older than perl in sid ($perl_version{sid})"
 	);
 
-	my @ordered_ideal_dep = $has_older_perl_in_sid ?
-		( \@ideal_perl_dep, \@ideal_lib_dep ) :
-		( \@ideal_lib_dep, \@ideal_perl_dep ) ;
+	my @ordered_ideal_dep
+        = $removed || $deprecated  ? ( \@ideal_lib_dep )
+        : $has_older_perl_in_sid ? ( \@ideal_perl_dep, \@ideal_lib_dep )
+        :                          ( \@ideal_lib_dep, \@ideal_perl_dep ) ;
 	my $ideal_dep = $self->struct_to_dep( @ordered_ideal_dep );
 
 	if ( $actual_dep ne $ideal_dep ) {
@@ -534,6 +540,12 @@ sub check_perl_lib_dep {
 		else {
 			$self->{nb_of_fixes}++;
 			my $msg = "Dependency of dual life package should be '$ideal_dep' not '$actual_dep'";
+            if ($removed) {
+                $msg .= " (removed from perl $removed)" ;
+            }
+            elsif ($deprecated) {
+                $msg .= " (deprecated from perl $deprecated)" ;
+            }
 			$self->add_warning ($msg);
 			$logger->info("will warn: $msg (fix++)");
 		}
