@@ -234,7 +234,7 @@ A package including binaries from grub2 and loadlin would have this field in its
         'type' => 'leaf',
         'value_type' => 'uniline',
         'warn_if_match' => {
-          '.{60,}' => {
+          '.{80,}' => {
             'msg' => 'Synopsis is too long. '
           }
         }
@@ -304,8 +304,8 @@ supported by the library',
       },
       'Build-Profiles',
       {
-        'description' => 'A space-separated list of optionally negated profile names',
-        'match' => '[!]?[a-z][a-z0-9-]*(\\s+[!]?[a-z][a-z0-9-]*)*',
+        'description' => 'A list of lists of (optionally negated) profile names, forming a conjunctive normal form expression in the same syntax as in the Build-Depends field',
+        'match' => '<!?[a-z0-9]+(?:\\s+!?[a-z0-9]+)*>(?:\\s+<!?[a-z0-9]+(?:\\s+!?[a-z0-9]+)*>)*',
         'type' => 'leaf',
         'value_type' => 'uniline'
       }
