@@ -78,21 +78,21 @@ area/section if the package is in the contrib or non-free archive areas.
       },
       'XS-Testsuite',
       {
-        'description' => 'Enable a testsuite to be used with this package. Currently only the \'autopkgtest\' name is allowed. For more details see L<README.package-tests|http://anonscm.debian.org/gitweb/?p=autopkgtest/autopkgtest.git;f=doc/README.package-tests;hb=HEAD>',
+        'description' => 'Enable a testsuite to be used with this package. For more details see L<README.package-tests.rst|https://anonscm.debian.org/cgit/autopkgtest/autopkgtest.git/plain/doc/README.package-tests.rst>',
         'status' => 'deprecated',
         'summary' => 'name of the non regression test suite',
         'type' => 'leaf',
         'value_type' => 'uniline',
         'warn_unless_match' => {
-          '^autopkgtest$' => {
+          '^autopkgtest(-pkg-(perl|ruby))?$' => {
             'fix' => '$_ = undef; # restore default value',
-            'msg' => 'Currently, only "autopkgtest" is supported'
+            'msg' => 'Unknown value'
           }
         }
       },
       'Testsuite',
       {
-        'description' => 'Enable a testsuite to be used with this package. Currently only the \'autopkgtest\' name is allowed. For more details see L<README.package-tests|http://anonscm.debian.org/gitweb/?p=autopkgtest/autopkgtest.git;f=doc/README.package-tests;hb=HEAD>',
+        'description' => 'Enable a testsuite to be used with this package. For more details see L<README.package-tests.rst|https://anonscm.debian.org/cgit/autopkgtest/autopkgtest.git/plain/doc/README.package-tests.rst>',
         'migrate_from' => {
           'formula' => '$xs_testsuite',
           'variables' => {
@@ -103,9 +103,9 @@ area/section if the package is in the contrib or non-free archive areas.
         'type' => 'leaf',
         'value_type' => 'uniline',
         'warn_unless_match' => {
-          '^autopkgtest$' => {
+          '^autopkgtest(-pkg-(perl|ruby))?$' => {
             'fix' => '$_ = undef; # restore default value',
-            'msg' => 'Currently, only "autopkgtest" is supported'
+            'msg' => 'Unknown value'
           }
         }
       },
@@ -190,16 +190,16 @@ in Debian developer reference.',
       },
       'Standards-Version',
       {
-        'default' => '3.9.5',
+        'default' => '3.9.6',
         'description' => 'This field indicates the debian policy version number this package complies to',
         'match' => '\\d+\\.\\d+\\.\\d+(\\.\\d+)?',
         'summary' => 'Debian policy version number this package complies to',
         'type' => 'leaf',
         'value_type' => 'uniline',
         'warn_unless_match' => {
-          '3\\.9\\.5' => {
+          '3\\.9\\.6' => {
             'fix' => '$_ = undef; # restore default value',
-            'msg' => 'Current standards version is 3.9.5'
+            'msg' => 'Current standards version is 3.9.6'
           }
         }
       },
@@ -207,7 +207,9 @@ in Debian developer reference.',
       {
         'compute' => {
           'allow_override' => '1',
-          'formula' => '$maintainer =~ /(pkg-(?:perl|ruby-extras))/ ? "http://anonscm.debian.org/gitweb/?p=$1/packages/$pkgname.git" : undef ;',
+          'formula' => '  $maintainer =~ /(pkg-perl)/                       ? "https://anonscm.debian.org/cgit/$1/packages/$pkgname.git"
+: $maintainer =~ /(pkg-(?:ruby-extras|javascript))/ ? "https://anonscm.debian.org/cgit/$1/$pkgname.git"
+:                                                     undef ;',
           'use_eval' => '1',
           'variables' => {
             'maintainer' => '- Maintainer',
@@ -223,9 +225,11 @@ The information is meant to be useful for the final user, willing to browse the
         'value_type' => 'uniline',
         'warn_unless' => {
           'debian-uri' => {
-            'code' => '!defined $_ or ! /debian.org/ or m{^https?://anonscm.debian.org/(viewvc|gitweb|loggerhead)} ;',
+            'code' => '!defined $_ or ! /debian.org/ or m{^https?://anonscm.debian.org/(viewvc|cgit|loggerhead)} ;',
             'fix' => 's{https?://svn\\.debian\\.org/\\w+svn/}{http://anonscm.debian.org/viewvc/};
-s{http://git.debian.org/\\?p=}{http://anonscm.debian.org/gitweb/?p=};
+s{http://git.debian.org/\\?p=}{https://anonscm.debian.org/cgit/};
+s{http://anonscm.debian.org/gitweb/\\?p=}{https://anonscm.debian.org/cgit/};
+s{(https://anonscm.debian.org/cgit/.+);a=summary}{$1};
 s{http://bzr.debian.org/loggerhead/}{http://anonscm.debian.org/loggerhead/};',
             'msg' => 'URL to debian system is not the recommended one'
           }
@@ -294,7 +298,9 @@ The information is meant to be useful for a user knowledgeable in the given Vers
       {
         'compute' => {
           'allow_override' => '1',
-          'formula' => '$maintainer =~ /(pkg-(?:perl|ruby-extras))/ ? "git://anonscm.debian.org/$1/packages/$pkgname.git" : \'\' ;',
+          'formula' => '  $maintainer =~ /(pkg-perl)/                        ? "git://anonscm.debian.org/$1/packages/$pkgname.git"
+: $maintainer =~ /(pkg-(?:ruby-extras|javascript))/  ? "git://anonscm.debian.org/$1/$pkgname.git"
+:                                                    \'\' ;',
           'use_eval' => '1',
           'variables' => {
             'maintainer' => '- Maintainer',
