@@ -32,15 +32,15 @@ To upgrade your file from an old spec, run:
     'element' => [
       'Format',
       {
-        'default' => 'http://www.debian.org/doc/packaging-manuals/copyright-format/1.0/',
+        'default' => 'https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/',
         'description' => 'URI of the format specification.',
         'mandatory' => '1',
-        'match' => '^http://',
+        'match' => '^https?://',
         'type' => 'leaf',
         'value_type' => 'uniline',
         'warn_unless_match' => {
-          '^http://www.debian.org/doc/packaging-manuals/copyright-format/1\\.0/?$' => {
-            'fix' => '$_ = \'http://www.debian.org/doc/packaging-manuals/copyright-format/1.0/\';',
+          '^https?://www.debian.org/doc/packaging-manuals/copyright-format/1\\.0/?$' => {
+            'fix' => '$_ = undef;',
             'msg' => 'Format does not match the recommended URL for DEP-5'
           }
         }
@@ -129,7 +129,7 @@ See L<files pattern documentation|https://www.debian.org/doc/packaging-manuals/c
       {
         'description' => 'White space separated list of file patterns to exclude from the package. This field is only used by L<uscan>. Example: C<*/Makefile.in aclocal.m4>. See also L<UscanEnhancements|https://wiki.debian.org/UscanEnhancements> and the L<files pattern documentation|https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/#files-field>.',
         'type' => 'leaf',
-        'value_type' => 'uniline'
+        'value_type' => 'string'
       },
       'Global-License',
       {
