@@ -22,17 +22,20 @@ check: license alternate(s?) <reject: $text or not $found or not $ok >
 alternate: comma(?) oper license 
 comma: \',\'
 oper: \'and\' | \'or\' 
-license: /[^\\s,]+/i
+abbrev: /[^\\s,]+/
+exception: \'with\' abbrev \'exception\' { join(\' \',@item[1..3]); }
+license: abbrev exception(?)
    { # PRD action to check if the license text is provided
-     my $abbrev = $item[1] ;
+     my $short_name = $item[1] ;
+	 $short_name .= \' \'.$item[2][0] if $item[2][0] ;
      $found++ ;
      my $elt = $arg[0]->grab(step => "!Dpkg::Copyright License", mode => \'strict\', type => \'hash\') ;
-     if ($elt->defined($abbrev) or $arg[0]->grab("- full_license")->fetch) {
+     if ($elt->defined($short_name) or $arg[0]->grab("- full_license")->fetch) {
         $ok &&= 1;
      }
      else { 
      	 $ok = 0 ;
-         ${$arg[1]} .= "license $abbrev is not declared in main License section. Expected ".join(" ",$elt->fetch_all_indexes) ;
+         ${$arg[1]} .= "license \'$short_name\' is not declared in main License section. Expected ".join(" ",$elt->fetch_all_indexes) ;
      }
    } ',
         'help' => {
@@ -87,38 +90,6 @@ license: /[^\\s,]+/i
           ]
         }
       },
-      'exception',
-      {
-        'description' => 'License exception',
-        'help' => {
-          'Font' => 'The GPL "Font" exception refers to the text added to the license notice of each file as specified at How_does_the_GPL_apply_to_fonts?. The precise text corresponding to this exception is:
-As a special exception, if you create a document which uses this
-font, and embed this font or unaltered portions of this font into the
-document, this font does not by itself cause the resulting document
-to be covered by the GNU General Public License. This exception does
-not however invalidate any other reasons why the document might be
-covered by the GNU General Public License. If you modify this font,
-you may extend this exception to your version of the font, but you
-are not obligated to do so. If you do not wish to do so, delete this
-exception statement from your version.',
-          'OpenSSL' => 'The GPL "OpenSSL" exception gives permission to link GPL-licensed code with the OpenSSL library, which contains GPL-incompatible clauses. For more information, see "The_-OpenSSL_License_and_The_GPL" by Mark McLoughlin and the message "middleman_software_license_conflicts_with_OpenSSL" by Mark McLoughlin on the debian-legal mailing list. The text corresponding to this exception is:
-In addition, as a special exception, the copyright holders give
-permission to link the code of portions of this program with the
-OpenSSL library under certain conditions as described in each
-individual source file, and distribute linked combinations including
-the two.
-
-You must obey the GNU General Public License in all respects for all
-of the code used other than OpenSSL. If you modify file(s) with this
-exception, you may extend this exception to your version of the file
-(s), but you are not obligated to do so. If you do not wish to do so,
-delete this exception statement from your version. If you delete this
-exception statement from all source files in the program, then also
-delete it here.'
-        },
-        'type' => 'leaf',
-        'value_type' => 'uniline'
-      },
       'full_license',
       {
         'description' => 'if left blank here, the file must include a stand-alone License section matching each license short name listed on the first line (see the Standalone License Section section). Otherwise, this field should either include the full text of the license(s) or include a pointer to the license file under /usr/share/common-licenses. This field should include all text needed in order to fulfill both Debian Policy requirement for including a copy of the software distribution license, and any license requirements to include warranty disclaimers or other notices with the binary package.
