@@ -22,15 +22,24 @@
         'compute' => {
           'allow_override' => '1',
           'formula' => 'require Software::LicenseUtils ;
-my $h = { 
-  short_name => &index( - ), 
-  holder => \'foo\' 
-} ;
+my $lic = &index( - ) ;
+my $h = { short_name => $lic, holder => \'foo\' } ;
+my $text;
 
-# no need to fail if short_name is unknown
-eval {
-  Software::LicenseUtils->new_from_short_name($h)->summary ; 
-} ;',
+if (defined $lic and $lic) {
+   # no need to fail if short_name is unknown
+   eval {
+       $text = Software::LicenseUtils->new_from_short_name($h)->debian_text ;
+   } ;
+
+# FIXME: find a way to warn user if a license is unknown only when
+# text is not set by another mean...
+#   if ($@ and ! $self->value_object->{data}) {
+#       print "Cannot find license text for $lic\\n" ;
+#   }
+}
+
+$text;',
           'undef_is' => '\'\'',
           'use_eval' => '1'
         },
