@@ -23,16 +23,16 @@ providing the following file:
             'source Build-Depends-Indep:0', "libcpan-meta-perl | perl (>= 5.13.10)",     # fixed
             'source Build-Depends-Indep:1', "libdist-zilla-perl",    # fixed
             'source Build-Depends-Indep:5', "libpath-class-perl",
-            'source Build-Depends-Indep:6', "perl (>= 5.11.3) | libmodule-build-perl (>= 0.36)", # fixed
+            'source Build-Depends-Indep:6', "libmodule-build-perl (>= 0.360000)", # fixed
             'source Build-Depends-Indep:7', "udev [linux-any] | makedev [linux-any]",
             'binary:libdist-zilla-plugins-cjm-perl Depends:0',
             '${misc:Depends}',
-            'source Vcs-Browser' ,'http://anonscm.debian.org/gitweb/?p=pkg-perl/packages/libdist-zilla-plugins-cjm-perl.git',
+            'source Vcs-Browser' ,'https://anonscm.debian.org/cgit/pkg-perl/packages/libdist-zilla-plugins-cjm-perl.git',
             'source Vcs-Git', 'git://anonscm.debian.org/pkg-perl/packages/libdist-zilla-plugins-cjm-perl.git',
         },
         load_warnings => [ qr/dependency/, qr/dual life/, (qr/dependency/) x 2, 
-                          qr/libmodule-build-perl \(>= 0.36\) \| perl \(>= 5.8.8\)/,
-                          qr/should be 'perl \(>= 5.11.3\) \| libmodule-build-perl \(>= 0.36\)/,
+                          qr/libmodule-build-perl \(>= 0.360000\) \| perl \(>= 5.8.8\)/,
+                          qr/should be 'libmodule-build-perl \(>= 0.360000\)/,
                           qr/standards version/, 
                            qr/dependency/, qr/dual life/, (qr/dependency/) x 2 ],
         apply_fix => 1,
@@ -168,7 +168,7 @@ providing the following file:
         load_warnings => [ qr/deprecated/  ],
         apply_fix => 1,
         check => {
-            'source Testsuite' => 'autopkgtest',
+            'source Testsuite' => 'autopkgtest-pkg-ruby',
         },
     },
     {
@@ -184,8 +184,8 @@ providing the following file:
         name => 'build-profiles',
         load_warnings => [ qr/standards version/ ],
         check => {
-            'binary:pkg-config Build-Profiles' => '!stage1',
-            'binary:pkg-config-stage1 Build-Profiles' => 'stage1',
+            'binary:pkg-config Build-Profiles' => '<!stage1>',
+            'binary:pkg-config-stage1 Build-Profiles' => '<stage1>',
         },
     }
 );
