@@ -2,7 +2,6 @@ use Data::Dumper;
 use IO::File;
 use File::HomeDir ;
 
-# keep in sync with the hardcoded value in Patch backend
 $conf_file_name = "some-patch";
 
 $conf_dir       = 'debian/patches';
@@ -14,9 +13,10 @@ $skip = ( $@ or not -r '/etc/debian_version' ) ? 1 : 0;
 @tests = (
     { 
         name => 'libperl5i' ,
-        dump_warnings => [qr/synopsis/],
-        # apply_fix => 1 ,
+        config_file => $conf_file_name,
+        apply_fix => 1 ,
         check => {
+            'Synopsis' => 'Some patch',
             'Bug:0' => 'https://github.com/schwern/perl5i/issues/218',
             'Bug:1' => 'https://github.com/schwern/perl5i/issues/219',
             'Origin' => 'https://github.com/doherty/perl5i',
